==> apache_airflow-2.6.0.dev20221218-py3-none-any.whl: airflow/www/static/js/dag/nav/LegendRow.test.tsx <==
/*!
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/* global describe, test, expect, stateColors, jest */

import React from 'react';
import { render, fireEvent, waitFor } from '@testing-library/react';

import LegendRow from './LegendRow';

describe('Test LegendRow', () => {
  test('Render displays correctly the different task states', () => {
    const onStatusHover = jest.fn();
    const onStatusLeave = jest.fn();
    const { getByText } = render(
      <LegendRow onStatusHover={onStatusHover} onStatusLeave={onStatusLeave} />,
    );

    Object.keys(stateColors).forEach((taskState) => {
      expect(getByText(taskState)).toBeInTheDocument();
    });

    expect(getByText('no_status')).toBeInTheDocument();
  });

  test.each([
    { state: 'success', expectedSetValue: 'success' },
    { state: 'failed', expectedSetValue: 'failed' },
    { state: 'no_status', expectedSetValue: null },
  ])(
    'Hovering $state badge should trigger setHoverdTaskState function with $expectedSetValue',
    async ({ state, expectedSetValue }) => {
      const onStatusHover = jest.fn();
      const onStatusLeave = jest.fn();
      const { getByText } = render(
        <LegendRow onStatusHover={onStatusHover} onStatusLeave={onStatusLeave} />,
      );
      const successElement = getByText(state);
      fireEvent.mouseEnter(successElement);
      await waitFor(() => expect(onStatusHover).toHaveBeenCalledWith(expectedSetValue));
      fireEvent.mouseLeave(successElement);
      await waitFor(() => expect(onStatusLeave).toHaveBeenLastCalledWith());
    },
  );
});

==> apache_airflow-2.9.1-py3-none-any.whl: airflow/www/static/js/dag/nav/LegendRow.test.tsx <==
/*!
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/* global describe, test, expect, stateColors, jest */

import React from "react";
import { render, fireEvent, waitFor } from "@testing-library/react";

import LegendRow from "./LegendRow";

describe("Test LegendRow", () => {
  test("Render displays correctly the different task states", () => {
    const onStatusHover = jest.fn();
    const onStatusLeave = jest.fn();
    const { getByText } = render(
      <LegendRow onStatusHover={onStatusHover} onStatusLeave={onStatusLeave} />
    );

    Object.keys(stateColors).forEach((taskState) => {
      expect(getByText(taskState)).toBeInTheDocument();
    });

    expect(getByText("no_status")).toBeInTheDocument();
  });

  test.each([
    { state: "success", expectedSetValue: "success" },
    { state: "failed", expectedSetValue: "failed" },
    { state: "no_status", expectedSetValue: null },
  ])(
    "Hovering $state badge should trigger setHoverdTaskState function with $expectedSetValue",
    async ({ state, expectedSetValue }) => {
      const onStatusHover = jest.fn();
      const onStatusLeave = jest.fn();
      const { getByText } = render(
        <LegendRow
          onStatusHover={onStatusHover}
          onStatusLeave={onStatusLeave}
        />
      );
      const successElement = getByText(state);
      fireEvent.mouseEnter(successElement);
      await waitFor(() =>
        expect(onStatusHover).toHaveBeenCalledWith(expectedSetValue)
      );
      fireEvent.mouseLeave(successElement);
      await waitFor(() => expect(onStatusLeave).toHaveBeenLastCalledWith());
    }
  );
});
